@@ -86,7 +86,7 @@
 #define KPARTS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPARTS_NO_DEPRECATED
-#  define KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
+#  define KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56700
 #endif
 #ifdef KPARTS_NO_DEPRECATED_WARNINGS
 #  define KPARTS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPARTS_DEPRECATED_WARNINGS_SINCE KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPARTS_DEPRECATED_WARNINGS_SINCE 0x56200
+#    define KPARTS_DEPRECATED_WARNINGS_SINCE 0x56700
 #  endif
 #endif
 
@@ -181,6 +181,12 @@
 #else
 #  define KPARTS_DEPRECATED_VERSION_5_90(text)
 #endif
+
+#if KPARTS_DEPRECATED_WARNINGS_SINCE >= 0x56700
+#  define KPARTS_DEPRECATED_VERSION_5_103(text) KPARTS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KPARTS_DEPRECATED_VERSION_5_103(text)
+#endif
 #define KPARTS_DEPRECATED_VERSION_3(minor, text)      KPARTS_DEPRECATED_VERSION_3_##minor(text)
 #define KPARTS_DEPRECATED_VERSION_4(minor, text)      KPARTS_DEPRECATED_VERSION_4_##minor(text)
 #define KPARTS_DEPRECATED_VERSION_5(minor, text)      KPARTS_DEPRECATED_VERSION_5_##minor(text)
@@ -248,7 +254,7 @@
 #define KPARTS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPARTS_NO_DEPRECATED
-#  define KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
+#  define KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56700
 #endif
 #ifdef KPARTS_NO_DEPRECATED_WARNINGS
 #  define KPARTS_DEPRECATED_WARNINGS_SINCE 0
@@ -258,7 +264,7 @@
 #  ifdef KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPARTS_DEPRECATED_WARNINGS_SINCE KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPARTS_DEPRECATED_WARNINGS_SINCE 0x56200
+#    define KPARTS_DEPRECATED_WARNINGS_SINCE 0x56700
 #  endif
 #endif
 
@@ -343,6 +349,12 @@
 #else
 #  define KPARTS_DEPRECATED_VERSION_5_90(text)
 #endif
+
+#if KPARTS_DEPRECATED_WARNINGS_SINCE >= 0x56700
+#  define KPARTS_DEPRECATED_VERSION_5_103(text) KPARTS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KPARTS_DEPRECATED_VERSION_5_103(text)
+#endif
 #define KPARTS_DEPRECATED_VERSION_3(minor, text)      KPARTS_DEPRECATED_VERSION_3_##minor(text)
 #define KPARTS_DEPRECATED_VERSION_4(minor, text)      KPARTS_DEPRECATED_VERSION_4_##minor(text)
 #define KPARTS_DEPRECATED_VERSION_5(minor, text)      KPARTS_DEPRECATED_VERSION_5_##minor(text)
